import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl(opts) {
    const domainToMappings = {
        'editor._base_domain_': [
            {
                srcPath: '/_api/synced-projects-service',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/synced-projects-service',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/synced-projects-service',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/synced-projects-service',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/portfolio_synced-project';
/** Get projects per app */
export function getProjects(payload) {
    function __getProjects({ host }) {
        const metadata = {
            entityFqdn: 'wix.portfolio.syncedprojects.v1.synced_project',
            method: 'GET',
            methodFqn: 'com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetProjects',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl({ protoPath: '/v1/projects/{appDefId}', data: payload, host }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'projects.lastSynced' }],
                },
            ]),
        };
        return metadata;
    }
    return __getProjects;
}
/** Async Sync project */
export function syncProject(payload) {
    function __syncProject({ host }) {
        const metadata = {
            entityFqdn: 'wix.portfolio.syncedprojects.v1.synced_project',
            method: 'POST',
            methodFqn: 'com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.SyncProject',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl({
                protoPath: '/v1/projects/{appDefId}/sync/{externalId}',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'project.lastSynced' }],
                },
            ]),
        };
        return metadata;
    }
    return __syncProject;
}
/** Get sync status (when was last synced and etc..) */
export function getSyncStatus(payload) {
    function __getSyncStatus({ host }) {
        const metadata = {
            entityFqdn: 'wix.portfolio.syncedprojects.v1.synced_project',
            method: 'GET',
            methodFqn: 'com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetSyncStatus',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl({
                protoPath: '/v1/projects/{appDefId}/sync/{externalId}/status',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __getSyncStatus;
}
/** Stop sync project */
export function stopSync(payload) {
    function __stopSync({ host }) {
        const metadata = {
            entityFqdn: 'wix.portfolio.syncedprojects.v1.synced_project',
            method: 'POST',
            methodFqn: 'com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.StopSync',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl({
                protoPath: '/v1/projects/{appDefId}/sync/{externalId}/stop',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __stopSync;
}
/** Get login redirectable url */
export function getLoginRedirectableUrl(payload) {
    function __getLoginRedirectableUrl({ host }) {
        const metadata = {
            entityFqdn: 'wix.portfolio.syncedprojects.v1.synced_project',
            method: 'POST',
            methodFqn: 'com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetLoginRedirectableUrl',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPortfolioSyncedprojectsSpiHostV1SyncedProjectsServiceUrl({ protoPath: '/v1/projects/login/url', data: payload, host }),
            data: payload,
        };
        return metadata;
    }
    return __getLoginRedirectableUrl;
}
//# sourceMappingURL=portfolio-syncedprojects-v1-synced-project-synced-project.http.js.map